@@ -45,13 +45,11 @@ GetOptions(
 # User asked for help
 pod2usage(-verbose => 1) if $option{help};
 
-my $width = $option{width} ? $option{width} : 15;
-
+# Make sure there is an input file
+pod2usage(-verbose => 0) unless @ARGV == 1;
 my $infile = shift;
-if (!$infile || !-f $infile) {
-    print STDERR "File '$infile' not found\n";
-    pod2usage(-verbose => 0);
-}
+
+my $width = $option{width} ? $option{width} : 15;
 
 # Default is croak if (recoverable) error found in encoded BUFR format
 my $strict_checking = defined $option{strict_checking}
